#include <SI_EFM8UB2_Register_Enums.h>                  // SFR declarations
#include "VCPXpress.h"
#include "descriptor.h"
#include "RGBSensorLEDFeedback_Defs.h"

uint16_t xdata USBBytesRcvd = 0;                   // Holds size of received packet
uint16_t xdata USBBytesTransmitted = 0;			//Holds number of bytes actually transmitted
uint8_t xdata USBRxPacket[USB_PACKET_SIZE];     // Packet received from host

bit REQUEST_RGBC_DATA = FALSE;
bit REQUEST_TEMP_DATA = FALSE;


/**************************************************************************//**
 * VCPXpress callback
 * This function is called by VCPXpress.
 *****************************************************************************/
VCPXpress_API_CALLBACK(myAPICallback)
{
   uint32_t API_InterruptCode;

   //get the code that indicates the reason for the interrupt
   API_InterruptCode = Get_Callback_Source();

   //if the USB connection was just opened
   if (API_InterruptCode & DEVICE_OPEN)
   {
	   //start the first USB read procedure
	   Block_Read(USBRxPacket, USB_PACKET_SIZE, &USBBytesRcvd);
	   /*we will process the received bytes when we get
	   a callback with an RX_COMPLETE interrupt code*/
   }

   if (API_InterruptCode & RX_COMPLETE)   // USB read complete
   {
	   //confirm that the received packet is the proper length
	   if(USBBytesRcvd == USB_CMD_LEN)
	   {
		   //'R' indicates that the host is Requesting data
		   if(USBRxPacket[0] == 'R')
		   {
			   //is the host requesting data from the RGBC sensor?
			   if(USBRxPacket[2] == 'R' && USBRxPacket[3] == 'G' && USBRxPacket[4] == 'B' && USBRxPacket[5] == 'C')
			   {
				   REQUEST_RGBC_DATA = TRUE;
			   }

			   //is the host requesting data from the thermocouple IC?
			   else if(USBRxPacket[2] == 'T' && USBRxPacket[3] == 'E' && USBRxPacket[4] == 'M' && USBRxPacket[5] == 'P')
			   {
				   REQUEST_TEMP_DATA = TRUE;
			   }
		   }
	   }

	   //continue with the next USB read procedure
	   Block_Read(USBRxPacket, USB_PACKET_SIZE, &USBBytesRcvd);
   }
}

void TransmitUSB_TempData()
{
		Block_Write(TempDataTx, TEMP_DATA_LEN, &USBBytesTransmitted);
}

void TransmitUSB_RGBCData()
{
		Block_Write(I2C_RcvData, RGBC_DATA_LEN, &USBBytesTransmitted);
}



